compute_ext

Macro compute_ext 

macro_rules! compute_ext {
    ($config:expr , $kernel:expr, $($data:expr),*) => { ... };
}
if you want to do have customized config for wgpu create compute_config and pass it as first arg to this macro